function obj = cut_addr(obj,istart,iend)
%CUT Extract data by address from a ts_data_channel object
% obj = cut(obj,start,end) creates a new ts_data_channel
% 		object containing only the data from start to end
%
%	start, end: start and end of data to cut (adresses, start at 1)

if nargout ==0, error('Must provide an output argument'); end

% Check validity of addresses
istart=round(istart); iend=round(iend);
ts_debug(1,'istart=%d, iend=%d\n',istart,iend);
numsamps = obj.nSamples;
if iend>numsamps; 
    ts_verbose(0,'iend (%d) > data length (%d): will not cut end',iend,numsamps);
    iend=numsamps;
end
checkAddresses(istart,iend,numsamps);

ts_verbose(1,'cutting from %d to %d', istart,iend);
% Cut the data
obj.data= obj.data(istart:iend);
if istart > 1,
    newstarttime = calcTime(obj,istart);
    obj.starttime=newstarttime;
end

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function checkAddresses(istart,iend,numsamps)

% Check for errors
if istart > iend,
	error('Start address (%d) is greater than end address (%d)', ...
			istart,iend);
end

if istart < 1,
		error('Start address (%d) is < 1',istart);
end

if iend > numsamps,
	error('End address (%d) > data length (%d)',iend,numsamps);
end
return;


