function fname = writeMSEED(chan,fname,format)
    % Write a ts_data_channel object to a miniSEED data file
    % Usage:
    % 	fName = writeMSEED(obj) creates a SEISAN-type miniSEED filename using the
    %					start time & inst name
    %	fName = writeMSEED(obj,outfilename) forces the output file name
    %
    %	fName = writeMSEED(obj,outfilename,format) specifies the output format
    %		 1 = 16-bit integer (default for class 2-bit, 8-bit, int16)
    %		 3 = 32-bit integer (default for class uint16, int32)
    %		 4 = IEEE float32 (default for class single)
    %		 5 = IEEE float64 (default for all other class)
    %		10 = Steim-1 compression (D will be converted to int32)
    %		11 = Steim-2 compression (D will be converted to int32)
    
    % W Crawford 11/2012
    
    ts_init;	% Sets up global variables
    
    if ~exist('fname','var'), fname = makeFileName(chan); end
    if ~exist('format','var'), format = 11; end
    ts_verbose(1,'Starting, will write file %s',fname);
    
    md=chan.metadata;
    f=fname;
    
    % Make miniSEED using 4096-byte record length
    tempfname=sprintf('%s.%s.%s.%s',md.network,md.station,md.location,md.component);
    %mkmseed(tempfname,chan.data,chan.starttime.toMatlabSerial(),chan.samprate,format,4096); % toMatlabSerial replaced by toDateNum()
    mkmseed(tempfname,chan.data,chan.starttime.toDateNum(),chan.samprate,format,4096);
    % Rename file to desired
    a=ls(sprintf('%s.*',upper(tempfname)));
    a=strtrim(a);   % Remove whitespaces at end and beginning
    if ~isempty(strfind(a,' ')),
        error('mkmseed made more than one file (you gave it more than one day?)');
    end
    movefile(a,f);
    ts_verbose(0,'File %s moved to %s',a,f);
    
    %mkmseed_tiskit(f,c);
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function fname = makeFileName(chan)
    % MAKE SEISAN-TYPE NAME, BASED ON FIRST TIME IN FILE
    
    a = getFirstLastTime(chan);
    a=round(a); % Round first time to the nearest second
    
    % PUT STATION NAME IN FILENAME
    instStr = chan.metadata.station;
    instStr = [instStr '_____']; instStr=instStr(1:5);  % Pad with underscores
    
    % CREATE FILENAME
    fname = sprintf('%sM.%5s_001',a.char('%y-%m-%d-%H%M-%S'),instStr);
end
