function [boundsbox,info] = calcplotpos(obj,varargin)
%CALCPLOTPOS Decide where to put a plot on a figure
% [x,y,w,h] = calcplotpos(obj,numplots,plot#,option)
%    by default, as close to an equal # of rows and columns are created, with
%
%    numplots is the number of subplots to make
%    plot# is the number of the current plot
%    options: 'allrows'  stacks plots on top of each other
%             'allcolumns' stacks plots side by side
%             'rows&cols' approx equal # of rows and columns [DEFAULT]
%             'xlabelBottomOnly' only allow space for x labels in bottom row [DEFAULT]
%             'xlabelAll' allow space for x labels in all rows
%             'ylabelLeftOnly' only allow space for y labels in left column
%             'ylabelAll' allow space for y labels in all columns [DEFAULT]
%
%	Outputs:
%		info.isTop, info.isBottom, info.isLeft, info.isRight, info.isDiag

numplots = varargin{1};
plotnum  = varargin{2};
nr = ceil(sqrt(numplots));
nc = ceil(numplots/nr);
makexlabelspace = 0;
makeylabelspace = 1;
if length(varargin)>2,
    for i = 3:length(varargin),
        switch varargin{i},
            case {'allrows','onecolumn','vstack'},
                nr = numplots;
                nc = 1;
            case {'allcols','onerow','hstack'},
                nr = 1; nc = numplots;
            case {'xlabelAll'},
                makexlabelspace = 1;
            case {'ylabelLeftOnly'},
                makeylabelspace = 0;
            otherwise,
                ts_warning('Undefined option: %s',varargin{i});
        end
    end
end

% read in data parameters
%fontsize =	obj.fontsize;
set(gcf,'Units','Characters');temp=get(gcf,'Position'); FigureXChars = temp(3); FigureYLines = temp(4);
set(gcf,'Units','Points');temp=get(gcf,'Position'); FigureXPts = temp(3); FigureYPts = temp(4);
norm_oneliney = 1.5/FigureYLines;
norm_onelinex = norm_oneliney*(FigureYPts/FigureXPts);
norm_onecharx = 1.1/FigureXChars;
xtextspace = 1.5*norm_onelinex + 6*norm_onecharx;
ytextspace = 2.2*norm_oneliney;
pos_x0 = xtextspace;
pos_y0 = ytextspace+ (obj.bottomoffset)/FigureYPts;
pos_h = 1-2*norm_oneliney-pos_y0;
pos_w = 1-2*norm_onelinex-xtextspace;
if makeylabelspace,
    delx = xtextspace;
else
    delx = 5/FigureXPts;    % 5 points between tiled plots
end
dely = ytextspace*makexlabelspace + 5/FigureYPts;   % 5 points between tiled plots

h = (pos_h - (nr-1)*dely)/nr;
w = (pos_w - (nc-1)*delx)/nc;
row = (nr+1)-ceil(plotnum/nc);	% Row counted from bottom
col = rem(plotnum-1,nc)+1;
x = pos_x0 + (col-1)*(w+delx);
y = pos_y0 + (row-1)*(h+dely);

boundsbox = [x y w h];
row = nr-row+1;	% Row counted from top

info.isBottom=0; info.isTop=0; info.isDiag=0; info.isInvDiag=0; info.isLeft=0; info.isRight=0;
if row==nr, info.isBottom=1; end
if row==1,  info.isTop=1;    end
if row==col,info.isDiag=1;   end
if row==nc-col+1,info.isInvDiag=1;   end
if col==1,  info.isLeft=1;   end
if col==nc; info.isRight=1;  end
