function obj = guessFileFormat(obj)
% Guess the file's format based on the filename suffix
if ischar(obj.filename), testfname=obj.filename;
elseif iscell(obj.filename), testfname=obj.filename{1};
else error('filename not a character string or cell');
end
[p,f,ext]=fileparts(testfname);
if isempty(ext),
    error('Filename %s has no suffix, couldn''t determine data format',testfname);
end
suffixmap={ ...
    'AH',     {'AH'}; ...
    'SAC',    {'SAC'}; ...
    'BINARY', {'BIN'}; ...
    'MSEED',  {'MSEED','MSD'}; ...
    'WEBB',   {'WEBB','WBB'}; ...
    'SUDS',   {'DMX'}; ...
    'SEISAN', {'SEI'} ...
    };
% SET DEFAULT FILE FORMAT TO SAME AS EXTENSION
obj.format=upper(ext(2:end));

% CHECK IF THE EXTENSION IS MAPPED TO A FILE FORMAT
for i = 1:length(suffixmap),
    temp=strfind(suffixmap{i,2},obj.format);
    if ~isempty(temp{1})
        obj.format=suffixmap{i,1};
        break
    end
end

% VERIFY THAT THE EXTENSION EXISTS
readfunction=['read' obj.format '.m'];
if ~exist(readfunction,'file')
    error('Trying to set file format from extension, did not find %s',readfunction);
else
    ts_verbose(0,'Set file format to %s from extension',obj.format);
end
end
