function [tdata,dfile] = readTEMPLATE(dfile,startAt,readLen)
% READTEMPLATE TEMPLATE for reading a file into a ts_data object
    % tdata = readTEMPLATE(theFile) reads the entire file into an ts_data object
    % tdata = readTEMPLATE(theFile,startAt,readLen) reads part of the file
    %
    %	theFile can be a filename or an ts_file object with the filename
    %		parameter set to the correct value.  If the filename has wildcards,
    %		ts_file.read() will try to read all of the relevant files.
    %	startAt [0] is either a time (ts_datetime) or an offset in seconds from
    %		the begining of the file
    %	readLen [0] is the length in seconds to read (0=read to the file
    %	end).  If set to -1, the routine will return after reading the
    %	file information, but without reading the data;
    %	
    
    % PROGRAMMERS NOTES:
    % You only need to use the values startAt and readLen if the files are very long and
    % it is much more efficient to read only part of them.  Otherwise,
    % ts_file.read(), which calls these functions, will take care of
    % cutting the data down to the right size.
    %
    % Always fill in the dfile information as much as possible with
    % information from the data file, including dfile.privateFirstTime and
    % dfile.privateLastTime

    %%% ALSO, GO INTO ts_file/guessFileFormat.m and put the
    %%% possible file extensions in list

    %%%%%%%% START ALL read* WITH THESE LINES
    ts_debug(1,'Starting\n'); 
    tic;
    if ~exist('start','var'), start=0; end
    if ~exist('readLen','var'), readLen=0; end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if dfile.tzoffset,
        error('Time-zero correction should be taken care of in ts_file.read(), not here');
    end
    
    % GET FILE INFORMATION
    dfile=getFileInfo(dfile);       
    % IF READLEN < 0, return the file information without reading data
    if isa(readLen,'numeric'); if readLen<0, tdata=[]; return; end; end

    % OTHERWISE, READ THE DATA
    tdata=readTheData(dfile,startAt,readLen);  % tdata is a ts_data object, and you should set
                                % at least the data, sample rate and start time parameters

return;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function tdata=readTheData(dfile,start,readLen)
    % Function to read the data file.  All of the file information you need to read
    % should be in the ts_file object dfile.
    % If there are special parameters that need to be specified for your
    % data, they should be stored as a cell array in dfile.custom,
    % and their format described in the comments at the top of this file.
    
    fname =	dfile.filename;
    ts_verbose(1,'Reading XXXX file %s',fname);

    % If the file format needs custom parameters, they should be in
    % dfile.custom{}.  Check here to make sure they are and output an error
    % message explicitly saying what is missing if they are not.

    % checkCustom()

    % YOUR CODE GOES HERE
    % Put the data into a float32 row array (one channel per row) named "data".
    % Put the time of the first sample in the ts_time object "starttime"

    tdata = ts_data(data,samprate,dfile);
    tdata.starttime=startTime;  % or, if each channel has a different starttime, set each
                                % one using tdata.channel(i).starttime
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
dfile=getFileInfo(dfile); 
% READS metadata (instrument position, sample rate, start/end times, etc into the dfile object

% Programmers: stuff as much information as you can into the dfile object.  This allows
% Tiskit (or the user) to get information about the file without reading the whole thing
% If there isn't an appropriate parameter in ts_file, put the value in the "custom"
% cell array and note what values are will be returned in the custom array in the subroutine
% comments at the top of this file

% YOUR CODE HERE
return;
	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%function checkCustom()
%Use this if you have custom values in the .custom parameter
%return;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%function [startAddress,endAddress]=calcCutAddrs(tdata)
%% This routine will tell you what addresses to keep/read if you only want
%% to read part of the data
%    numsamps = get(tdata,'numsamps');
%    samprate = get(tdata,'samprate');
%
%    if isa(start,'ts_datetime'),
%        timeOffset = start-get(tdata,'chstarttime',1);
%        startAddress = round(timeOffset*samprate +1);
%    elseif start~=0,
%        startAddress = round(start*samprate +1);
%    else
%        startAddress = 1;
%    end
%    endAddress = numsamps-startAddress+1;
%    if  readLen~=0,
%        endAddress = startAddress+(readLen*samprate) - 1;
%    end
%return;
