function dfile = setColdDogParms
% Defines the ColdDog.

disp('Returns datafile for the ColdDog');
dfile = ts_file('????','WEBB');
% Set basic instrument parameters
dfile.ch_metadata(1).information='ColdDOG';
samprate=2;
dfile.nChannels=4;
% Set datafile parameters
bytesPerRec = 345088; byteswap=0; sampsPerRec = 43124;
headerAddresses = [1664 8190]; headerSize=16; timeStartAddr=4; clockRate=256;
dfile.custom={bytesPerRec,sampsPerRec,byteswap, ...
				headerAddresses,headerSize,timeStartAddr,clockRate,samprate,...
                ts_datetime('2000/01/01 00:00:00')};

% Channel 1: Cheat
dfile.ch_metadata(1).component='CHT';
resp1=ts_response('BW','m/s^2','counts',18100*1e5,2,1/6.28,0,[]);
resp2=ts_response('BW','','',1,1,1/.0628,0,[]);
resp3=ts_response('BW','','',1,2,1/.228,0,[]);
dfile.ch_metadata(1).response=resp1*resp2*resp3;
% Channel 2: DPG1
LRC1=7.5e3*1e-6; LRC2=100e3*1e-6; HRC=1e6*4.7e-6; % Card 1 
leakefold=518/(2*pi);	% Gauge 14, DC leak time constant from 1999 EPR post-cruise calibration
gainguess= 90;			% The gain needed to match 1995 TOES compliances
dfile.ch_metadata(2).component='DPG';
dfile.ch_metadata(2).location='01';
dfile.ch_metadata(2).response=ts_response('PZ','Pa','counts',gainguess,[-1/LRC1 -1/LRC2 -1/HRC -1/leakefold], [0 0], 1);
% Channel 3: DPG2
LRC1=3.16e3*1e-6; LRC2=100e3*0.33e-6; HRC=1e6*4.58e-6; % Card 1.  HPCap is officially 4.7
leakefold=518/(2*pi);	% Gain, efold and HC needed to match 1999 DPG1 (using data from site AA5b)
gainguess = 365;		
dfile.ch_metadata(3).component='DPG';
dfile.ch_metadata(3).location='02';
dfile.ch_metadata(3).response=ts_response('PZ','Pa','counts',gainguess,[-1/LRC1 -1/LRC2 -1/HRC -1/leakefold], [0 0],1);
% Channel 4: Multiplexed
dfile.ch_metadata(4).component='MUX';
