%% ts_data_figureproperties
% Data figure properties, a subclass of <ts_figureproperties_help.html
% |ts_figureproperties|>
%
%% Description
% This subclass adds time series plot-specific properties
%
%% Properties:
%
% <html>
% <table border="0" width="100%" cellpadding="10">
% <tr><td></td><td>NAME</td>        <td>DESCRIPTION</td><td>TYPE</td></tr>
% <tr><td></td><td>title</td>       <td>Figure title</td><td>character string</td>
% <tr><td></td><td>bottomoffset</td><td>Offset of bottom plot from figure bottom (points) [0]</td><td>numeric</td>
% <tr><td></td><td>overlay</td>     <td>If/how to overlay plots:<br>0=no overlay<br>-1=overlay with common scale<br>-2=overlay, each autoscaled<br>dely=overlay, each autoscaled and offset by dely of full scale</td><td>numeric</td>
% <tr><td></td><td>yscale</td>      <td>One of: 'default', 'linear', 'log', 'db'</td><td>character string</td>
% <tr><td></td><td>fontsize</td>    <td>Font size [10]</td><td>integer</td>
% <tr><td></td><td>xticks</td>      <td>Specify x ticks, empty uses default</td><td>numeric vector</td>
% <tr><td></td><td>xticklabels</td> <td>Specify x tick labels, empty uses default</td><td>cell vector of strings</td>
% <tr><td></td><td>xlabel</td>      <td>x label, empty uses default</td><td>character string</td>
% <tr><td></td><td>plotasmatrix</td><td>Organize plots in a matrix (COHERENCY ONLY)</td><td>boolean</td>
% <tr><td></td><td>nSubplots</td>   <td>Number of subplots</td><td>integer</td>
% <tr><td></td><td>subplot</td>     <td>Subplot properties</td><td>ts_figureproperties_subplot vector</td>
% <tr><th colspan="4" align="left">Time series specific</th>
% <tr><td></td><td>decimtype</td>   <td>'smart' or 'regular'</td><td>character string</td>
% <tr><td></td><td>smartdecim</td>  <td>Plot up to X points</td><td>integer</td>
% <tr><td></td><td>regdecim</td>    <td>Plot every X points</td><td>integer</td>
% </table>
% </html>
%
%
%% Methods:
%  ts_data_figureproperties - Creator
%  addtitle                 - Add a title to the plot (called by plot routines)
%  calcplotpos              - Calculate the position for a subplot
%
%% Examples
fp=ts_data_figureproperties
%%
fp.nSubplots=5
%%
fp.calcplotpos(fp.nSubplots,1)
%%
fp.calcplotpos(fp.nSubplots,2)
%%
fp.calcplotpos(fp.nSubplots,2,'allrows')

%% See also
% <ts_figureproperties_subplot_help.html |ts_figureproperties_subplot|>
