%% ts_spectrogram
% Store and plot spectrograms created by ts_data_channel.calcSpectrogram()
%
%% Properties:
%     data       - Spectrogram data
%     freqs      - Spectrogram frequencies
%     starttime  - time of first spectrum     (ts_datetime)
%     toffsets   - offset from starttime of each PSD  (seconds)
%     units      - PSD data units
%     name       - Channel name
%     endtime    - READONLY: time of last spectrum
%     nSpectra   - READONLY: number of spectra in spectrogram
%
%% Methods:
%     ts_spectrogram - Constructor
%     plus           - Combine two spectrograms
%     plot           - Plot spectrogram
%
%% Examples
% Set up time scale
sps=1; days = 30; 
firstDay='2007/07/04'; 

% Make data
t=1:1/sps:days*86400;                 % Set up time vector
d=sin(t/(5*86400/pi)).*rand(size(t)); % Make a modulated time signal

% Put data into a ts_data channel object and plot 
tsc = ts_data_channel(d,sps);         % Create ts_data_channel object
tsc.starttime=firstDay;               % Set the data start time
figure(1); plot(tsc);                 % Plot time series
%%
% Calculate and plot spectrogram
sgram=tsc.calcSpectrogram(40000,86400); % Make spectrogram: daily spectra
									 % using 40000-second windows
figure(2); plot(sgram);
%% See Also
% <ts_datetime_help.html |ts_datetime|>, <ts_data_channel_help.html |ts_data_channel|>