function sgram=makeSpectrograms_LCPO(tsf,spectWLen,spectLen,numDays)
    % Makes a spectrogram for each channel of an LCPO file
    % Usage:
    %   sgrams=makeSpectrograms_LCPO(tsf,[spectWLen],[spectLen],[length])
    %
    % Inputs:
    %   tsf         is a ts_file object containing the filename and correct
    %               instrument responses and channel names (can be made
    %               using the command tsf_LCPO_L22(),tsf_LCPO_L28() or
    %               tsf_LCPO_T240(), depending on the OBS you used)
    %   spectWLen	is the length of each FFT (seconds, default=1000)
    %   spectLen	is the length of each spectrum (seconds, default=3600*6)
    %   numDays      is the number of days to process (0=all=default)
    
    ts_verbose(-1); ts_debug(0);
    
    %% Database read method
    
    dt=1;   % Read interval (1 day): only used for DPGs, APG data read whole
    if ~exist('spectWLen','var'),
        spectWLen=1000; % Each FFT is calulated using this time (seconds)
    end
    if ~exist('spectLen','var')
        spectLen=3600*6;% Each spectrum is calculated over this time (seconds)
    end
    if ~exist('numDays','var')
        numDays=0; % Days of spectrum to calculate (0 means all)
    end
    
    [~,info]=tsf.read(0,1); % Returns start and end times
    startDN=info.firstTime.toDateNum();
    endDN=  info.lastTime.toDateNum();
    if numDays~=0 && startDN+numDays < endDN
        endDN=startDN+numDays;
        fprintf('Calculating spectra for first %g days of data\n',numDays);
    end
    
    for theDateNum = startDN:dt:endDN
        fprintf('%s\n',datestr(theDateNum));
        %d = ts_file.readDB('SDS',directory,ts_datetime(theDateNum),86400*dt, 'component=LHZ');
        d = tsf.read(ts_datetime(theDateNum),86400*dt);
        for i=1:d.nChannels,
            sg_1=d.channel(i).calcSpectrogram(spectWLen,spectLen);
            if ~exist('sgram','var');
                sgram{i}=sg_1;
            elseif length(sgram)<i,
                sgram{i}=sg_1;
            else
                sgram{i}=sgram{i}+sg_1;
            end
        end
    end
    for i=1:length(sgram)
        cmp=d.channel(i).metadata.component;
        station=d.channel(i).metadata.station;
        filebase=sprintf('%s_%s_%s-%s_%dh_spectro',station,cmp,datestr(startDN,'yyyymmdd'),datestr(endDN,'yyyymmdd'),spectLen/3600);
        figure(i); plot(sgram{i});
        print('-dpdf',[filebase '.pdf']);
        print('-dpng','-r300',[filebase '.png']);
    end
    
    % filebase=sprintf('%s_%s-%s_%dh_spectro',station,datestr(startDN,'yyyymmdd'),datestr(endDN,'yyyymmdd'),spectLen/3600);
    %save(['spectrograms/' filebase '.mat'],'sgram');
    
end