function thefile=tsf_LCPO_T240(theInput,SN,year)
    % tsf_LCPO_T240 creates a ts_file instance for an L-Cheapo T240 logger
    %
    % Usage: tsf=tsf_LCPO_T240(theInput,SN,year);
    %
    % Inputs:
    %   theInput    is either a filename or a ts_file object
    %   SN          is the serial number (1-9)                        [1]
    %   year        is the deployment year (important for Z channel)[2012+]
    if ~exist('SN','var')
        SN=1;
    else
        if ~isnumeric(SN)
            SN=str2num(SN);
        end
    end
    if ~exist('year')
        year=2012;
    end
    
    if isa(theInput,'ts_file'),
        if theInput.nChannels~=4,
            error('You tried to force a %d-channel ts_file object to be an LCPO_T240')
        end
        thefile=theInput;
    else
        thefile=ts_file(theInput,'LCPO');
        thefile.nChannels=4;
    end
    
    % Enter channel names ('B' is for samprate=10-80, 'H' for samprate>80,'M'=1.001-10, L~1, V~0.1
    thefile.ch_metadata(1).component='BH2'; % channel 1 =  X =  H2
    thefile.ch_metadata(2).component='BH1'; % channel 2 =  Y =  H1
    thefile.ch_metadata(3).component='BHZ'; % channel 3 =  Z =  HZ
    thefile.ch_metadata(4).component='BDH'; % channel 4 = DPG = DH
    
    % Enter standard instrument response
    thefile.ch_metadata(1).response=tsresp_LCPO_T240('H',SN,year);
    thefile.ch_metadata(2).response=tsresp_LCPO_T240('H',SN,year);
    thefile.ch_metadata(3).response=tsresp_LCPO_T240('Z',SN,year);
    
    % Enter DPG response
    switch (SN)
        case {1,21},
            thefile.ch_metadata(4).response=tsresp_LCPO_DPG('L21_DPG5004_2007');
        case {2,22},
            thefile.ch_metadata(4).response=tsresp_LCPO_DPG('L22_DPG5018_2007');
        otherwise,
            switch SN,
                case {3,4,5,6,7,8,9},
                    text=sprintf('BBOBS%02d DPG is uncalibrated',SN)
                case 0,
                    text='No serial number provided'
                otherwise,
                    text=sprintf('UNKNOWN SERIAL # %02d',SN)
            end
            ts_warning('%s, using BBOBS21_DPG5004_2007 response!!!!!!',text)
            thefile.ch_metadata(4).response=tsresp_LCPO_DPG('L21_DPG5004_2007');
    end
end

